@@ -25,7 +25,7 @@ def api_auth(token, secret, url=None):
         URL = url
 
 
-def api_call(method, path, data=None, params=None, no_auth=False):
+def api_call(method, path, data=None, params=None, no_auth=False, raw=False):
     if no_auth:
         auth_headers = {}
     else:
@@ -57,6 +57,9 @@ def api_call(method, path, data=None, params=None, no_auth=False):
     r.raise_for_status()
 
     try:
-        return r.json()
+        if raw:
+            return r.text
+        else:
+            return r.json()
     except ValueError:
         raise Exception("Error parsing API response to JSON: [%d] %s" % (r.status_code, r.text))
